@@ -21,7 +21,7 @@ pub fn trim_paf_rec_to_rgn(rgn: &bed::Region, paf: &PafRecord) -> Option<PafReco
 
     // check if we can return right away
     if paf.t_st > rgn.st && paf.t_en < rgn.en {
-        return Some(trimmed_paf);
+        return Some(paf.clone());
     }
 
     // index at the start of trimmed alignment
@@ -48,6 +48,14 @@ pub fn trim_paf_rec_to_rgn(rgn: &bed::Region, paf: &PafRecord) -> Option<PafReco
     if trimmed_paf.cigar.len() == 0 {
         return None;
     }
+    if trimmed_paf.q_st > trimmed_paf.q_en || trimmed_paf.t_st > trimmed_paf.t_en {
+        eprintln!(
+            "Warning: liftover of {} failed. {} > {} or {} > {}",
+            rgn, trimmed_paf.q_st, trimmed_paf.q_en, trimmed_paf.t_st, trimmed_paf.t_en
+        );
+        return None;
+    }
+
     Some(trimmed_paf)
 }
 
